=== added file 'CMakeLists.txt'
--- CMakeLists.txt	1970-01-01 00:00:00 +0000
+++ CMakeLists.txt	2013-04-15 12:05:00 +0000
@@ -0,0 +1,30 @@
+project(gallery-app)
+cmake_minimum_required(VERSION 2.8.9)
+set(CMAKE_MODULE_PATH "${CMAKE_CURRENT_SOURCE_DIR}/cmake")
+
+# Find includes in corresponding build directories
+set(CMAKE_INCLUDE_CURRENT_DIR ON)
+
+# Instruct CMake to run moc automatically when needed.
+set(CMAKE_AUTOMOC ON)
+
+find_package(Qt5Qml)
+find_package(Qt5Quick)
+find_package(Qt5Gui)
+find_package(OpenGL)
+find_package(Exiv2)
+
+include(FindPkgConfig)
+
+# Standard install paths
+include(GNUInstallDirs)
+
+set(GALLERY_DIR ${CMAKE_INSTALL_DATADIR}/gallery-app)
+
+# Tests
+enable_testing()
+
+add_subdirectory(desktop)
+add_subdirectory(rc)
+add_subdirectory(src)
+add_subdirectory(tests)

=== added directory 'cmake'
=== added file 'cmake/FindExiv2.cmake'
--- cmake/FindExiv2.cmake	1970-01-01 00:00:00 +0000
+++ cmake/FindExiv2.cmake	2013-04-15 12:05:00 +0000
@@ -0,0 +1,3 @@
+find_path(EXIV2_INCLUDE_DIR NAMES exiv2/exif.hpp)
+find_library(EXIV2_LIBRARY NAMES exiv2 libexiv2)
+set(EXIV2_LIBRARIES "${EXIV2_LIBRARY}")

=== added file 'cmake/autopilot.cmake'
--- cmake/autopilot.cmake	1970-01-01 00:00:00 +0000
+++ cmake/autopilot.cmake	2013-04-15 12:05:00 +0000
@@ -0,0 +1,38 @@
+add_custom_target(autopilot)
+
+option(ENABLE_AUTOPILOT "Enable or Disable autopilot tests" On)
+option(AUTOPILOT_RECORD "Enable or Disable autopilot record tests" OFF)
+option(AUTOPILOT_RECORD_PATH "Directory to put recorded tests" OFF)
+
+if(ENABLE_AUTOPILOT)
+    find_program(AUTOPILOT_BIN autopilot)
+    if(AUTOPILOT_BIN)
+        message(STATUS "Autopilot tests enabled.")
+    else()
+        message(STATUS "Autopilot tests disabled: autopilot binary not found")
+    endif()
+endif()
+
+if(AUTOPILOT_RECORD OR AUTOPILOT_RECORD_PATH)
+    find_program(AUTOPILOT_REC_BIN recordmydesktop)
+    if(AUTOPILOT_REC_BIN)
+        message(STATUS "Record autopilot enabled")
+        if(AUTOPILOT_RECORD_PATH)
+            message(STATUS "Save autopilot tests video in: ${AUTOPILOT_RECORD_PATH}")
+            set(AUTOPILOT_TESTS_ARGS -r -rd ${AUTOPILOT_RECORD_PATH})
+        else()
+            set(AUTOPILOT_TESTS_ARGS -r)
+        endif()
+    else()
+        message(STATUS "recordmydesktop necessary for record autopilot tests not found.")
+        set(AUTOPILOT_TESTS_ARGS "")
+    endif()
+endif()
+
+function(declare_autopilot_test ENVIROMENT TEST_NAME WORKING_DIR)
+    if(AUTOPILOT_BIN)
+        add_custom_command(TARGET autopilot
+            COMMAND ${ENVIROMENT} autopilot run ${TEST_NAME} ${AUTOPILOT_TESTS_ARGS}
+            WORKING_DIRECTORY ${WORKING_DIR}) 
+    endif()
+endfunction()

=== removed file 'coverage.pri'
--- coverage.pri	2013-01-17 10:42:37 +0000
+++ coverage.pri	1970-01-01 00:00:00 +0000
@@ -1,49 +0,0 @@
-# Coverage
-CONFIG(coverage) {
-    OBJECTS_DIR =
-    MOC_DIR =
-    TOP_SRC_DIR = $$PWD
-
-    LIBS += -lgcov
-    QMAKE_CXXFLAGS += --coverage
-    QMAKE_LDFLAGS += --coverage
-
-    QMAKE_EXTRA_TARGETS += coverage cov
-    QMAKE_EXTRA_TARGETS += clean-gcno clean-gcda coverage-html \
-        generate-coverage-html clean-coverage-html coverage-xml \
-        generate-gcovr generate-coverage-xml clean-coverage-xml
-
-    clean-gcno.commands = \
-        "@echo Removing old coverage instrumentation"; \
-        "find -name '*.gcno' -print | xargs -r rm"
-
-    clean-gcda.commands = \
-        "@echo Removing old coverage results"; \
-        "find -name '*.gcda' -print | xargs -r rm"
-  
-    coverage-html.depends = clean-gcda check generate-coverage-html
-  
-    generate-coverage-html.commands = \
-        "@echo Collecting coverage data"; \
-        "lcov --directory $${TOP_SRC_DIR} --capture --output-file coverage.info --no-checksum --compat-libtool"; \
-        "lcov --extract coverage.info \"*/src/*.cpp\" -o coverage.info"; \
-        "lcov --remove coverage.info \"moc_*.cpp\" -o coverage.info"; \
-        "LANG=C genhtml --prefix $${TOP_SRC_DIR} --output-directory coverage-html --title \"Code Coverage\" --legend --show-details coverage.info"
-  
-    clean-coverage-html.depends = clean-gcda
-    clean-coverage-html.commands = \
-        "lcov --directory $${TOP_SRC_DIR} -z"; \
-        "rm -rf coverage.info coverage-html"
-
-    coverage-xml.depends = clean-gcda check generate-coverage-xml
-
-    generate-coverage-xml.commands = \
-        "@echo Generating coverage GCOVR report"; \
-        "gcovr -x -r $${TOP_SRC_DIR} -o $${TOP_SRC_DIR}/coverage.xml -e \".*/moc_.*\" -e \"unittests/.*\" -e \".*\\.h\""
-
-    clean-coverage-xml.depends = clean-gcda
-    clean-coverage-xml.commands = \
-        "rm -rf $${TOP_SRC_DIR}/coverage.xml"
-
-    QMAKE_CLEAN += *.gcda *.gcno coverage.info coverage.xml
-}

=== modified file 'debian/gallery-app.install'
--- debian/gallery-app.install	2013-04-04 14:03:54 +0000
+++ debian/gallery-app.install	2013-04-15 12:05:00 +0000
@@ -1,4 +1,4 @@
-desktop/gallery-app.desktop /usr/share/applications
-desktop/icons/* /usr/share/icons
-src/gallery-app /usr/bin
+usr/bin/gallery-app
+usr/share/applications
 usr/share/gallery-app
+usr/share/icons

=== modified file 'debian/rules'
--- debian/rules	2013-03-27 16:16:52 +0000
+++ debian/rules	2013-04-15 12:05:00 +0000
@@ -4,8 +4,7 @@
 export QT_QPA_PLATFORM = minimal
 
 %:
-	dh $@ --parallel --buildsystem=qmake
+	dh $@ --parallel
 
 override_dh_install:
-	rm -r debian/tmp/usr/tests
 	dh_install --fail-missing

=== added file 'desktop/CMakeLists.txt'
--- desktop/CMakeLists.txt	1970-01-01 00:00:00 +0000
+++ desktop/CMakeLists.txt	2013-04-15 12:05:00 +0000
@@ -0,0 +1,10 @@
+install(FILES gallery-app.desktop 
+    DESTINATION ${CMAKE_INSTALL_DATADIR}/applications
+    )
+
+install(DIRECTORY icons/hicolor DESTINATION DESTINATION
+    ${CMAKE_INSTALL_DATADIR}/icons FILES_MATCHING PATTERN *.png
+    )
+install(DIRECTORY icons/ubuntu-mobile DESTINATION DESTINATION
+    ${CMAKE_INSTALL_DATADIR}/icons FILES_MATCHING PATTERN *.png
+    )

=== removed file 'gallery-app.pro'
--- gallery-app.pro	2013-03-28 12:30:06 +0000
+++ gallery-app.pro	1970-01-01 00:00:00 +0000
@@ -1,7 +0,0 @@
-include(coverage.pri)
-
-TEMPLATE = subdirs
-SUBDIRS += \
-    rc \
-    src \
-    tests

=== added file 'gallery-app.qmlproject'
--- gallery-app.qmlproject	1970-01-01 00:00:00 +0000
+++ gallery-app.qmlproject	2013-04-15 12:05:00 +0000
@@ -0,0 +1,20 @@
+/* File generated by Qt Creator, version 2.5.2 */
+
+import QmlProject 1.1
+
+Project {
+    mainFile: "rc/qml/GalleryApplication.qml"
+
+    /* Include .qml, .js, and image files from current directory and subdirectories */
+    QmlFiles {
+        directory: ["rc/qml", "rc/Capetown"]
+    }
+    JavaScriptFiles {
+        directory: "rc/js"
+    }
+    ImageFiles {
+        directory: ["rc/img", "rc/Capetown/Widgets/img",
+            "rc/qml/Widgets/img", "rc/qml/Utility/img",
+            "../rc/qml/Components/img", "../rc/qml/Components/AlbumInternalsimg"]
+    }
+}

=== added file 'rc/CMakeLists.txt'
--- rc/CMakeLists.txt	1970-01-01 00:00:00 +0000
+++ rc/CMakeLists.txt	2013-04-15 12:05:00 +0000
@@ -0,0 +1,7 @@
+set(GALLERY_RC_DIR ${CMAKE_INSTALL_PREFIX}/${GALLERY_DIR}/rc)
+
+install(DIRECTORY Capetown DESTINATION ${GALLERY_RC_DIR} FILES_MATCHING PATTERN *)
+install(DIRECTORY img DESTINATION ${GALLERY_RC_DIR} FILES_MATCHING PATTERN *)
+install(DIRECTORY js DESTINATION ${GALLERY_RC_DIR} FILES_MATCHING PATTERN *)
+install(DIRECTORY qml DESTINATION ${GALLERY_RC_DIR} FILES_MATCHING PATTERN *)
+install(DIRECTORY sql DESTINATION ${GALLERY_RC_DIR} FILES_MATCHING PATTERN *)

=== removed file 'rc/rc.pro'
--- rc/rc.pro	2013-03-18 14:14:05 +0000
+++ rc/rc.pro	1970-01-01 00:00:00 +0000
@@ -1,17 +0,0 @@
-include(../coverage.pri)
-
-isEmpty(PREFIX) {
-  PREFIX = /usr/local
-}
-
-TEMPLATE = aux
-
-DEFINES += "INSTALL_PREFIX=\\\"$$PREFIX\\\""
-QMAKE_RESOURCE_FLAGS += -root .
-
-# Install
-
-install_resources.path = $$PREFIX/share/gallery-app/
-install_resources.files = .
-INSTALLS = install_resources
-

=== added file 'src/CMakeLists.txt'
--- src/CMakeLists.txt	1970-01-01 00:00:00 +0000
+++ src/CMakeLists.txt	2013-04-15 12:05:00 +0000
@@ -0,0 +1,121 @@
+project(gallery_src)
+
+configure_file(
+    config.h.in
+    ${CMAKE_CURRENT_BINARY_DIR}/config.h
+    @ONLY
+    )
+
+set(GALLERY gallery-app)
+
+include_directories(
+    ${CMAKE_BINARY_DIR}
+    ${EXIV2_INCLUDEDIR}
+    ${GSTLIB_INCLUDE_DIRS}
+    )
+
+set(gallery_HDRS
+    gallery-application.h
+    album/album.h
+    album/album-collection.h
+    album/album-default-template.h
+    album/album-page.h
+    album/album-template.h
+    album/album-template-page.h
+    core/command-line-parser.h
+    core/container-source.h
+    core/container-source-collection.h
+    core/data-collection.h
+    core/data-object.h
+    core/data-source.h
+    core/gallery-manager.h
+    core/selectable-view-collection.h
+    core/source-collection.h
+    core/view-collection.h
+    database/album-table.h
+    database/database.h
+    database/media-table.h
+    database/photo-edit-table.h
+    event/event.h
+    event/event-collection.h
+    media/media-collection.h
+    media/media-monitor.h
+    media/media-source.h
+    media/preview-manager.h
+    photo/photo.h
+    photo/photo-caches.h
+    photo/photo-edit-state.h
+    photo/photo-metadata.h
+    qml/gallery-standard-image-provider.h
+    qml/gallery-thumbnail-image-provider.h
+    qml/qml-album-collection-model.h
+    qml/qml-event-collection-model.h
+    qml/qml-event-overview-model.h
+    qml/qml-media-collection-model.h
+    qml/qml-view-collection-model.h
+    util/collections.h
+    util/imaging.h
+    util/resource.h
+    util/sharefile.h
+    util/variants.h
+    )
+
+set(gallery_SRCS
+    gallery-application.cpp
+    main.cpp
+    album/album.cpp
+    album/album-default-template.cpp
+    album/album-collection.cpp
+    album/album-page.cpp
+    album/album-template.cpp
+    album/album-template-page.cpp
+    core/command-line-parser.cpp
+    core/container-source.cpp
+    core/container-source-collection.cpp
+    core/data-collection.cpp
+    core/data-object.cpp
+    core/data-source.cpp
+    core/gallery-manager.cpp
+    core/selectable-view-collection.cpp
+    core/source-collection.cpp
+    core/view-collection.cpp
+    database/album-table.cpp
+    database/database.cpp
+    database/media-table.cpp
+    database/photo-edit-table.cpp
+    event/event.cpp
+    event/event-collection.cpp
+    media/media-collection.cpp
+    media/media-monitor.cpp
+    media/media-source.cpp
+    media/preview-manager.cpp
+    photo/photo.cpp
+    photo/photo-caches.cpp
+    photo/photo-edit-state.cpp
+    photo/photo-metadata.cpp
+    qml/gallery-standard-image-provider.cpp
+    qml/gallery-thumbnail-image-provider.cpp
+    qml/qml-album-collection-model.cpp
+    qml/qml-event-collection-model.cpp
+    qml/qml-event-overview-model.cpp
+    qml/qml-media-collection-model.cpp
+    qml/qml-view-collection-model.cpp
+    util/imaging.cpp
+    util/resource.cpp
+    util/sharefile.cpp
+    )
+
+add_executable(${GALLERY}
+    ${gallery_MOC_SRCS}
+    ${gallery_SRCS}
+    )
+
+qt5_use_modules(${GALLERY} Widgets Core Qml Quick OpenGL Sql)
+
+target_link_libraries( ${GALLERY}
+    ${EXIV2_LIBRARIES}
+    ${OPENGL_LIBRARIES}
+    ${GSTLIB_LDFLAGS}
+    )
+
+install(TARGETS ${GALLERY} RUNTIME DESTINATION ${CMAKE_INSTALL_BINDIR})

=== added file 'src/config.h.in'
--- src/config.h.in	1970-01-01 00:00:00 +0000
+++ src/config.h.in	2013-04-15 12:05:00 +0000
@@ -0,0 +1,41 @@
+/*
+ * Copyright 2013 Canonical Ltd.
+ *
+ * This file is part of webbrowser-app.
+ *
+ * webbrowser-app is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 3.
+ *
+ * webbrowser-app is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
+#ifndef __CONFIG_H__
+#define __CONFIG_H__
+
+#include <QtCore/QCoreApplication>
+#include <QtCore/QDir>
+#include <QtCore/QString>
+
+inline bool isRunningInstalled()
+{
+    static bool installed = (QCoreApplication::applicationDirPath() == QDir("@CMAKE_INSTALL_FULL_BINDIR@").canonicalPath());
+    return installed;
+}
+
+inline QString galleryDirectory()
+{
+    if (isRunningInstalled()) {
+        return QString("@CMAKE_INSTALL_PREFIX@/@GALLERY_DIR@");
+    } else {
+        return QString("@gallery_src_SOURCE_DIR@");
+    }
+}
+
+#endif // __CONFIG_H__

=== modified file 'src/core/gallery-manager.cpp'
--- src/core/gallery-manager.cpp	2013-03-27 07:48:50 +0000
+++ src/core/gallery-manager.cpp	2013-04-15 12:05:00 +0000
@@ -40,19 +40,19 @@
  * \param log_image_loading if true, the image loadings times are printed to stdout
  * \return
  */
-GalleryManager* GalleryManager::instance(const QString &application_path_dir, const QDir &pictures_dir,
+GalleryManager* GalleryManager::instance(const QDir &pictures_dir,
                                          QQuickView *view, const bool log_image_loading)
 {
     if (!gallery_mgr_)
-        gallery_mgr_ = new GalleryManager(application_path_dir, pictures_dir, view, log_image_loading);
+        gallery_mgr_ = new GalleryManager(pictures_dir, view, log_image_loading);
 
     return gallery_mgr_;
 }
 
-GalleryManager::GalleryManager(const QString& application_path_dir, const QDir& pictures_dir,
+GalleryManager::GalleryManager(const QDir& pictures_dir,
                                QQuickView *view, const bool log_image_loading)
     : collections_initialised(false),
-      resource_(new Resource(application_path_dir, INSTALL_PREFIX, view)),
+      resource_(new Resource(view)),
       gallery_standard_image_provider_(new GalleryStandardImageProvider(log_image_loading)),
       gallery_thumbnail_image_provider_(new GalleryThumbnailImageProvider(log_image_loading)),
       database_(NULL),

=== modified file 'src/core/gallery-manager.h'
--- src/core/gallery-manager.h	2013-03-27 07:48:50 +0000
+++ src/core/gallery-manager.h	2013-04-15 12:05:00 +0000
@@ -42,8 +42,7 @@
 class GalleryManager
 {
 public:
-    static GalleryManager* instance(const QString& application_path_dir = QString(),
-                                    const QDir& pictures_dir = QDir(),
+    static GalleryManager* instance(const QDir& pictures_dir = QDir(),
                                     QQuickView *view = 0,
                                     const bool log_image_loading = false);
 
@@ -63,7 +62,7 @@
     GalleryThumbnailImageProvider* gallery_thumbnail_image_provider() { return gallery_thumbnail_image_provider_; }
 
 private:
-    GalleryManager(const QString& application_path_dir, const QDir& pictures_dir, QQuickView *view,
+    GalleryManager(const QDir& pictures_dir, QQuickView *view,
                    const bool log_image_loading);
     ~GalleryManager();
 

=== modified file 'src/gallery-application.cpp'
--- src/gallery-application.cpp	2013-03-27 07:48:50 +0000
+++ src/gallery-application.cpp	2013-04-15 12:05:00 +0000
@@ -67,7 +67,7 @@
 
     register_qml();
 
-    GalleryManager::instance(applicationDirPath(), cmd_line_parser()->pictures_dir(), &view_,
+    GalleryManager::instance(cmd_line_parser()->pictures_dir(), &view_,
                              cmd_line_parser()->log_image_loading());
 }
 

=== removed file 'src/src.pro'
--- src/src.pro	2013-03-18 14:14:05 +0000
+++ src/src.pro	1970-01-01 00:00:00 +0000
@@ -1,115 +0,0 @@
-isEmpty(PREFIX) {
-	PREFIX = /usr/local
-}
-
-TEMPLATE = app
-TARGET = gallery-app
-CONFIG += qt link_pkgconfig
-QMAKE_CXXFLAGS += -Werror -Wno-unused-parameter
-DEFINES += "INSTALL_PREFIX=\\\"$$PREFIX\\\""
-QT += gui qml quick opengl sql
-MOC_DIR = build
-OBJECTS_DIR = build
-RCC_DIR = build
-PKGCONFIG += exiv2
-DEFINES += QT_USE_QSTRINGBUILDER
-
-include(../coverage.pri)
-
-# Input
-
-SOURCES += \
-  gallery-application.cpp \
-  main.cpp \
-  album/album.cpp \
-  album/album-default-template.cpp \
-  album/album-collection.cpp \
-  album/album-page.cpp \
-  album/album-template.cpp \
-  album/album-template-page.cpp \
-  core/command-line-parser.cpp \
-  core/container-source.cpp \
-  core/container-source-collection.cpp \
-  core/data-collection.cpp \
-  core/data-object.cpp \
-  core/data-source.cpp \
-  core/gallery-manager.cpp \
-  core/selectable-view-collection.cpp \
-  core/source-collection.cpp \
-  core/view-collection.cpp \
-  database/album-table.cpp \
-  database/database.cpp \
-  database/media-table.cpp \
-  database/photo-edit-table.cpp \
-  event/event.cpp \
-  event/event-collection.cpp \
-  media/media-collection.cpp \
-  media/media-monitor.cpp \
-  media/media-source.cpp \
-  media/preview-manager.cpp \
-  photo/photo.cpp \
-  photo/photo-caches.cpp \
-  photo/photo-edit-state.cpp \
-  photo/photo-metadata.cpp \
-  qml/gallery-standard-image-provider.cpp \
-  qml/gallery-thumbnail-image-provider.cpp \
-  qml/qml-album-collection-model.cpp \
-  qml/qml-event-collection-model.cpp \
-  qml/qml-event-overview-model.cpp \
-  qml/qml-media-collection-model.cpp \
-  qml/qml-view-collection-model.cpp \
-  util/imaging.cpp \
-  util/resource.cpp \
-  util/sharefile.cpp
-
-HEADERS += \
-  gallery-application.h \
-  album/album.h \
-  album/album-collection.h \
-  album/album-default-template.h \
-  album/album-page.h \
-  album/album-template.h \
-  album/album-template-page.h \
-  core/command-line-parser.h \
-  core/container-source.h \
-  core/container-source-collection.h \
-  core/data-collection.h \
-  core/data-object.h \
-  core/data-source.h \
-  core/gallery-manager.h \
-  core/selectable-view-collection.h \
-  core/source-collection.h \
-  core/view-collection.h \
-  database/album-table.h \
-  database/database.h \
-  database/media-table.h \
-  database/photo-edit-table.h \
-  event/event.h \
-  event/event-collection.h \
-  media/media-collection.h \
-  media/media-monitor.h \
-  media/media-source.h \
-  media/preview-manager.h \
-  photo/photo.h \
-  photo/photo-caches.h \
-  photo/photo-edit-state.h \
-  photo/photo-metadata.h \
-  qml/gallery-standard-image-provider.h \
-  qml/gallery-thumbnail-image-provider.h \
-  qml/qml-album-collection-model.h \
-  qml/qml-event-collection-model.h \
-  qml/qml-event-overview-model.h \
-  qml/qml-media-collection-model.h \
-  qml/qml-view-collection-model.h \
-  util/collections.h \
-  util/imaging.h \
-  util/resource.h \
-  util/sharefile.h \
-  util/variants.h
-
-# Install
-
-install_binary.path = $$PREFIX/bin/
-install_binary.files = gallery
-INSTALLS = install_binary
-

=== modified file 'src/util/resource.cpp'
--- src/util/resource.cpp	2013-03-27 08:13:15 +0000
+++ src/util/resource.cpp	2013-04-15 12:05:00 +0000
@@ -18,6 +18,7 @@
  */
 
 #include "resource.h"
+#include "config.h"
 
 #include <QtGui/QOpenGLContext>
 #include <QtQuick/QQuickView>
@@ -28,35 +29,10 @@
  * \param install_dir the directory, where apps are installed to
  * \param view the view is used to determine the max texture size
  */
-Resource::Resource(const QString& application_dir, const QString& install_dir, QQuickView *view)
+Resource::Resource(QQuickView *view)
     : view_(view),
       max_texture_size_(0)
 {
-    app_dir_ = QDir(application_dir);
-    if (trailing_slash(app_dir_.absolutePath()).endsWith("/bin/"))
-        app_dir_.cdUp();
-
-    install_dir_ = QDir(install_dir);
-}
-
-/*!
- * \brief Resource::is_installed
- * Return if the is run from an installed appl or from a local place.
- * \return Returns true if we're installed, false if we're running locally.
- */
-bool Resource::is_installed() const
-{
-    return app_dir_ == install_dir_;
-}
-
-/*!
- * \brief Resource::trailing_slash
- * \param path
- * \return
- */
-QString Resource::trailing_slash(QString path) const
-{
-    return path.endsWith("/") ? path : path + "/";
 }
 
 /*!
@@ -68,9 +44,9 @@
  */
 QUrl Resource::get_rc_url(const QString& path) const
 {
-    return is_installed() ?
-                QUrl::fromLocalFile(trailing_slash(install_dir_.path()) + "share/gallery-app/rc/" + path) :
-                QUrl::fromLocalFile(trailing_slash(app_dir_.path()) + "../rc/" + path);
+    return isRunningInstalled() ?
+                QUrl::fromLocalFile(galleryDirectory() + "/share/gallery-app/rc/" + path) :
+                QUrl::fromLocalFile(galleryDirectory() + "/../rc/" + path);
 }
 
 /*!

=== modified file 'src/util/resource.h'
--- src/util/resource.h	2013-03-27 07:48:50 +0000
+++ src/util/resource.h	2013-04-15 12:05:00 +0000
@@ -19,7 +19,6 @@
 #ifndef RESOURCE_H
 #define RESOURCE_H
 
-#include <QDir>
 #include <QString>
 #include <QUrl>
 
@@ -31,9 +30,7 @@
 class Resource
 {
 public:
-    explicit Resource(const QString& application_dir, const QString& install_dir, QQuickView *view);
-
-    bool is_installed() const;
+    explicit Resource(QQuickView *view);
 
     QUrl get_rc_url(const QString& path) const;
 
@@ -42,10 +39,6 @@
     void setView(QQuickView* view);
 
 private:
-    QString trailing_slash(QString path) const;
-
-    QDir app_dir_;
-    QDir install_dir_;
     QQuickView* view_;
     mutable int max_texture_size_;
 

=== added file 'tests/CMakeLists.txt'
--- tests/CMakeLists.txt	1970-01-01 00:00:00 +0000
+++ tests/CMakeLists.txt	2013-04-15 12:05:00 +0000
@@ -0,0 +1,2 @@
+add_subdirectory(autopilot)
+add_subdirectory(unittests)

=== added file 'tests/autopilot/CMakeLists.txt'
--- tests/autopilot/CMakeLists.txt	1970-01-01 00:00:00 +0000
+++ tests/autopilot/CMakeLists.txt	2013-04-15 12:05:00 +0000
@@ -0,0 +1,14 @@
+set(AUTOPILOT_DIR gallery_app)
+
+execute_process(COMMAND python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()"
+    OUTPUT_VARIABLE PYTHON_PACKAGE_DIR OUTPUT_STRIP_TRAILING_WHITESPACE)
+
+install(DIRECTORY ${AUTOPILOT_DIR}
+    DESTINATION ${PYTHON_PACKAGE_DIR}
+    )
+
+include(${CMAKE_SOURCE_DIR}/cmake/autopilot.cmake)
+declare_autopilot_test(GALLERY_APP=${gallery_src_BINARY_DIR}/gallery-app
+    ${AUTOPILOT_DIR} ${CMAKE_CURRENT_SOURCE_DIR}
+    )
+

=== removed file 'tests/autopilot/autopilot.pro'
--- tests/autopilot/autopilot.pro	2013-03-28 12:30:06 +0000
+++ tests/autopilot/autopilot.pro	1970-01-01 00:00:00 +0000
@@ -1,14 +0,0 @@
-include(../../coverage.pri)
-
-isEmpty(PREFIX) {
-  PREFIX = /usr/local
-}
-
-TEMPLATE = aux
-DEFINES += "INSTALL_PREFIX=\\\"$$PREFIX\\\""
-
-# Install
-
-install_autopilot.path = $$PREFIX/lib/python2.7/dist-packages/
-install_autopilot.files = gallery_app
-INSTALLS = install_autopilot

=== removed file 'tests/tests.pro'
--- tests/tests.pro	2013-03-28 12:30:06 +0000
+++ tests/tests.pro	1970-01-01 00:00:00 +0000
@@ -1,6 +0,0 @@
-include(../coverage.pri)
-
-TEMPLATE = subdirs
-SUBDIRS += \
-    autopilot \
-    unittests

=== added file 'tests/unittests/CMakeLists.txt'
--- tests/unittests/CMakeLists.txt	1970-01-01 00:00:00 +0000
+++ tests/unittests/CMakeLists.txt	2013-04-15 12:05:00 +0000
@@ -0,0 +1,5 @@
+add_subdirectory(command-line-parser)
+add_subdirectory(gallerystandardimageprovider)
+add_subdirectory(gallerythumbnailimageprovider)
+add_subdirectory(imaging)
+add_subdirectory(resource)

=== added file 'tests/unittests/command-line-parser/CMakeLists.txt'
--- tests/unittests/command-line-parser/CMakeLists.txt	1970-01-01 00:00:00 +0000
+++ tests/unittests/command-line-parser/CMakeLists.txt	2013-04-15 12:05:00 +0000
@@ -0,0 +1,26 @@
+add_definitions(-DTEST_SUITE)
+
+if(NOT CTEST_TESTING_TIMEOUT)
+    set(CTEST_TESTING_TIMEOUT 60)
+endif()
+
+include_directories(
+    ${CMAKE_BINARY_DIR}
+    ${gallery_src_SOURCE_DIR}
+    ${GSTLIB_INCLUDE_DIRS}
+    )
+
+add_executable(command-line-parser
+    tst_commandlineparser.cpp
+    ${gallery_src_SOURCE_DIR}/core/command-line-parser.cpp
+    )
+
+qt5_use_modules(command-line-parser Quick Test)
+add_test(command-line-parser command-line-parser -xunitxml -o test_resource.xml)
+set_tests_properties(command-line-parser PROPERTIES
+    TIMEOUT ${CTEST_TESTING_TIMEOUT}
+    ENVIRONMENT "QT_QPA_PLATFORM=minimal"
+    )
+target_link_libraries(command-line-parser 
+    ${GSTLIB_LDFLAGS}
+    )

=== removed file 'tests/unittests/command-line-parser/command-line-parser.pro'
--- tests/unittests/command-line-parser/command-line-parser.pro	2013-03-28 12:30:06 +0000
+++ tests/unittests/command-line-parser/command-line-parser.pro	1970-01-01 00:00:00 +0000
@@ -1,16 +0,0 @@
-CONFIG += testcase
-TARGET = tst_commandlineparser
-
-QT += testlib quick gui
-
-BASE_PATH = "../../.."
-include($${BASE_PATH}/coverage.pri)
-
-INCLUDEPATH += $${BASE_PATH}/src/qml \
-               $${BASE_PATH}/src
-
-SOURCES += tst_commandlineparser.cpp \
-    $${BASE_PATH}/src/core/command-line-parser.cpp
-
-HEADERS += \
-    $${BASE_PATH}/src/core/command-line-parser.h

=== added file 'tests/unittests/gallerystandardimageprovider/CMakeLists.txt'
--- tests/unittests/gallerystandardimageprovider/CMakeLists.txt	1970-01-01 00:00:00 +0000
+++ tests/unittests/gallerystandardimageprovider/CMakeLists.txt	2013-04-15 12:05:00 +0000
@@ -0,0 +1,31 @@
+add_definitions(-DTEST_SUITE)
+
+if(NOT CTEST_TESTING_TIMEOUT)
+    set(CTEST_TESTING_TIMEOUT 60)
+endif()
+
+include_directories(
+    ${CMAKE_BINARY_DIR}
+    ${gallery_src_SOURCE_DIR}
+    ${GSTLIB_INCLUDE_DIRS}
+    )
+
+add_executable(gallerystandardimageprovider
+    tst_gallerystandardimageprovidertest.cpp
+    gallery-manager.cpp
+    preview-manager.cpp
+    photometa-data.cpp
+    ${gallery_src_SOURCE_DIR}/qml/gallery-standard-image-provider.cpp
+    )
+
+qt5_use_modules(gallerystandardimageprovider Quick Test)
+add_test(gallerystandardimageprovider gallerystandardimageprovider
+    -xunitxml -o test_resource.xml
+    )
+set_tests_properties(gallerystandardimageprovider PROPERTIES
+    TIMEOUT ${CTEST_TESTING_TIMEOUT}
+    ENVIRONMENT "QT_QPA_PLATFORM=minimal"
+    )
+target_link_libraries(gallerystandardimageprovider 
+    ${GSTLIB_LDFLAGS}
+    )

=== modified file 'tests/unittests/gallerystandardimageprovider/gallery-manager.cpp'
--- tests/unittests/gallerystandardimageprovider/gallery-manager.cpp	2013-03-27 07:48:50 +0000
+++ tests/unittests/gallerystandardimageprovider/gallery-manager.cpp	2013-04-15 12:05:00 +0000
@@ -25,7 +25,7 @@
 
 GalleryManager* GalleryManager::gallery_mgr_ = NULL;
 
-GalleryManager::GalleryManager(const QString&, const QDir& pictures_dir, QQuickView*, const bool)
+GalleryManager::GalleryManager(const QDir& pictures_dir, QQuickView*, const bool)
     : collections_initialised(false),
       resource_(NULL),
       gallery_standard_image_provider_(NULL),
@@ -46,11 +46,11 @@
     gallery_mgr_ = NULL;
 }
 
-GalleryManager* GalleryManager::instance(const QString& application_path_dir, const QDir& pictures_dir,
+GalleryManager* GalleryManager::instance(const QDir& pictures_dir,
                                          QQuickView* view, const bool)
 {
     if (!gallery_mgr_)
-        gallery_mgr_ = new GalleryManager(application_path_dir, pictures_dir, view, false);
+        gallery_mgr_ = new GalleryManager(pictures_dir, view, false);
 
     return gallery_mgr_;
 }

=== removed file 'tests/unittests/gallerystandardimageprovider/gallerystandardimageprovider.pro'
--- tests/unittests/gallerystandardimageprovider/gallerystandardimageprovider.pro	2013-03-28 12:30:06 +0000
+++ tests/unittests/gallerystandardimageprovider/gallerystandardimageprovider.pro	1970-01-01 00:00:00 +0000
@@ -1,22 +0,0 @@
-CONFIG += testcase
-TARGET = tst_gallerystandardimageprovider
-
-QT += testlib quick gui
-
-BASE_PATH = "../../.."
-include($${BASE_PATH}/coverage.pri)
-
-INCLUDEPATH += $${BASE_PATH}/src/qml \
-               $${BASE_PATH}/src
-
-SOURCES += \
-    tst_gallerystandardimageprovidertest.cpp \
-    $${BASE_PATH}/src/qml/gallery-standard-image-provider.cpp \
-    gallery-manager.cpp \
-    preview-manager.cpp \
-    photometa-data.cpp
-
-HEADERS += \
-    $${BASE_PATH}/src/qml/gallery-standard-image-provider.h \
-    $${BASE_PATH}/src/core/gallery-manager.h \
-    $${BASE_PATH}/src/media/preview-manager.h

=== added file 'tests/unittests/gallerythumbnailimageprovider/CMakeLists.txt'
--- tests/unittests/gallerythumbnailimageprovider/CMakeLists.txt	1970-01-01 00:00:00 +0000
+++ tests/unittests/gallerythumbnailimageprovider/CMakeLists.txt	2013-04-15 12:05:00 +0000
@@ -0,0 +1,30 @@
+add_definitions(-DTEST_SUITE)
+
+if(NOT CTEST_TESTING_TIMEOUT)
+    set(CTEST_TESTING_TIMEOUT 60)
+endif()
+
+include_directories(
+    ${CMAKE_BINARY_DIR}
+    ${gallery_src_SOURCE_DIR}
+    ${GSTLIB_INCLUDE_DIRS}
+    )
+
+add_executable(gallerythumbnailimageprovider
+    tst_gallerythumbnailimageprovider.cpp
+    gallery-manager.cpp
+    preview-manager.cpp
+    ${gallery_src_SOURCE_DIR}/qml/gallery-thumbnail-image-provider.cpp
+    )
+
+qt5_use_modules(gallerythumbnailimageprovider Quick Test)
+add_test(gallerythumbnailimageprovider gallerythumbnailimageprovider
+    -xunitxml -o test_resource.xml
+    )
+set_tests_properties(gallerythumbnailimageprovider PROPERTIES
+    TIMEOUT ${CTEST_TESTING_TIMEOUT}
+    ENVIRONMENT "QT_QPA_PLATFORM=minimal"
+    )
+target_link_libraries(gallerythumbnailimageprovider 
+    ${GSTLIB_LDFLAGS}
+    )

=== modified file 'tests/unittests/gallerythumbnailimageprovider/gallery-manager.cpp'
--- tests/unittests/gallerythumbnailimageprovider/gallery-manager.cpp	2013-03-27 07:48:50 +0000
+++ tests/unittests/gallerythumbnailimageprovider/gallery-manager.cpp	2013-04-15 12:05:00 +0000
@@ -27,7 +27,7 @@
 
 GalleryManager* GalleryManager::gallery_mgr_ = NULL;
 
-GalleryManager::GalleryManager(const QString&, const QDir& pictures_dir, QQuickView*, const bool)
+GalleryManager::GalleryManager(const QDir& pictures_dir, QQuickView*, const bool)
     : collections_initialised(false),
       resource_(NULL),
       gallery_standard_image_provider_(NULL),
@@ -49,11 +49,11 @@
     gallery_mgr_ = NULL;
 }
 
-GalleryManager* GalleryManager::instance(const QString& application_path_dir, const QDir& pictures_dir,
+GalleryManager* GalleryManager::instance(const QDir& pictures_dir,
                                          QQuickView* view, const bool log_image_loading)
 {
     if (!gallery_mgr_)
-        gallery_mgr_ = new GalleryManager(application_path_dir, pictures_dir, view, log_image_loading);
+        gallery_mgr_ = new GalleryManager(pictures_dir, view, log_image_loading);
 
     return gallery_mgr_;
 }

=== removed file 'tests/unittests/gallerythumbnailimageprovider/gallerythumbnailimageprovider.pro'
--- tests/unittests/gallerythumbnailimageprovider/gallerythumbnailimageprovider.pro	2013-03-28 12:30:06 +0000
+++ tests/unittests/gallerythumbnailimageprovider/gallerythumbnailimageprovider.pro	1970-01-01 00:00:00 +0000
@@ -1,19 +0,0 @@
-CONFIG += testcase
-TARGET = tst_gallerythumbnailimageprovider
-
-QT += testlib quick
-
-BASE_PATH = "../../.."
-include($${BASE_PATH}/coverage.pri)
-
-SOURCES += tst_gallerythumbnailimageprovider.cpp \
-    $${BASE_PATH}/src/qml/gallery-thumbnail-image-provider.cpp \
-    gallery-manager.cpp \
-    preview-manager.cpp
-
-INCLUDEPATH += $${BASE_PATH}/src/qml \
-               $${BASE_PATH}/src
-
-HEADERS += $${BASE_PATH}/src/core/gallery-manager.h \
-           $${BASE_PATH}/src/media/preview-manager.h
-

=== added file 'tests/unittests/imaging/CMakeLists.txt'
--- tests/unittests/imaging/CMakeLists.txt	1970-01-01 00:00:00 +0000
+++ tests/unittests/imaging/CMakeLists.txt	2013-04-15 12:05:00 +0000
@@ -0,0 +1,26 @@
+add_definitions(-DTEST_SUITE)
+
+if(NOT CTEST_TESTING_TIMEOUT)
+    set(CTEST_TESTING_TIMEOUT 60)
+endif()
+
+include_directories(
+    ${CMAKE_BINARY_DIR}
+    ${gallery_src_SOURCE_DIR}
+    ${GSTLIB_INCLUDE_DIRS}
+    )
+
+add_executable(imaging
+    tst_imaging.cpp
+    ${gallery_src_SOURCE_DIR}/util/imaging.cpp
+    )
+
+qt5_use_modules(imaging Quick Widgets Test)
+add_test(imaging imaging -xunitxml -o test_resource.xml)
+set_tests_properties(imaging PROPERTIES
+    TIMEOUT ${CTEST_TESTING_TIMEOUT}
+    ENVIRONMENT "QT_QPA_PLATFORM=minimal"
+    )
+target_link_libraries(imaging 
+    ${GSTLIB_LDFLAGS}
+    )

=== removed file 'tests/unittests/imaging/imaging.pro'
--- tests/unittests/imaging/imaging.pro	2013-03-28 12:30:06 +0000
+++ tests/unittests/imaging/imaging.pro	1970-01-01 00:00:00 +0000
@@ -1,12 +0,0 @@
-CONFIG += testcase
-TARGET = tst_imaging
-
-QT += testlib widgets
-
-BASE_PATH = "../../.."
-include($${BASE_PATH}/coverage.pri)
-
-SOURCES += tst_imaging.cpp \
-    $${BASE_PATH}/src/util/imaging.cpp
-
-INCLUDEPATH += $${BASE_PATH}/src

=== added file 'tests/unittests/resource/CMakeLists.txt'
--- tests/unittests/resource/CMakeLists.txt	1970-01-01 00:00:00 +0000
+++ tests/unittests/resource/CMakeLists.txt	2013-04-15 12:05:00 +0000
@@ -0,0 +1,32 @@
+add_definitions(-DTEST_SUITE)
+
+if(NOT CTEST_TESTING_TIMEOUT)
+    set(CTEST_TESTING_TIMEOUT 60)
+endif()
+
+configure_file(
+    ${gallery_src_SOURCE_DIR}/config.h.in
+    ${CMAKE_CURRENT_BINARY_DIR}/config.h
+    @ONLY)
+
+include_directories(
+    ${CMAKE_BINARY_DIR}
+    ${gallery_src_SOURCE_DIR}
+    ${GSTLIB_INCLUDE_DIRS}
+    )
+
+add_executable(resource
+    tst_resource.cpp
+    ${gallery_src_SOURCE_DIR}/util/resource.cpp
+    )
+
+qt5_use_modules(resource Quick Test)
+add_test(resource resource -xunitxml -o test_resource.xml)
+set_tests_properties(resource PROPERTIES
+    TIMEOUT ${CTEST_TESTING_TIMEOUT}
+    ENVIRONMENT "QT_QPA_PLATFORM=minimal"
+    )
+target_link_libraries(resource 
+    ${OPENGL_LIBRARIES}
+    ${GSTLIB_LDFLAGS}
+    )

=== removed file 'tests/unittests/resource/resource.pro'
--- tests/unittests/resource/resource.pro	2013-03-28 14:43:25 +0000
+++ tests/unittests/resource/resource.pro	1970-01-01 00:00:00 +0000
@@ -1,12 +0,0 @@
-CONFIG += testcase
-TARGET = tst_resource
-
-QT += testlib quick
-
-BASE_PATH = "../../.."
-include($${BASE_PATH}/coverage.pri)
-
-SOURCES += tst_resource.cpp \
-    $${BASE_PATH}/src/util/resource.cpp
-
-INCLUDEPATH += $${BASE_PATH}/src

=== modified file 'tests/unittests/resource/tst_resource.cpp'
--- tests/unittests/resource/tst_resource.cpp	2013-03-27 07:48:50 +0000
+++ tests/unittests/resource/tst_resource.cpp	2013-04-15 12:05:00 +0000
@@ -27,70 +27,12 @@
   Q_OBJECT
 
 private slots:
-    void is_installed_data();
-    void is_installed();
-
-    void trailing_slash();
-
-    void get_rc_url_data();
-    void get_rc_url();
-
     void maxTextureSize();
 };
 
-
-void tst_Resource::is_installed_data()
-{
-    QTest::addColumn<QString>("appDir");
-    QTest::addColumn<QString>("installDir");
-    QTest::addColumn<bool>("installed");
-
-    QTest::newRow("system") << QString("/usr/bin") << QString("/usr") << true;
-    QTest::newRow("local") << QString("/home/user/dev/gallery") << QString("/usr") << false;
-}
-void tst_Resource::is_installed()
-{
-    QFETCH(QString, appDir);
-    QFETCH(QString, installDir);
-    QFETCH(bool, installed);
-
-    Resource resource(appDir, installDir, 0);
-    QCOMPARE(resource.is_installed(), installed);
-}
-
-void tst_Resource::trailing_slash()
-{
-    Resource resource("", "", 0);
-    QCOMPARE(resource.trailing_slash("/usr"), QString("/usr/"));
-    QCOMPARE(resource.trailing_slash("/usr/"), QString("/usr/"));
-}
-
-void tst_Resource::get_rc_url_data()
-{
-    QTest::addColumn<QString>("appDir");
-    QTest::addColumn<QString>("installDir");
-    QTest::addColumn<QString>("path");
-    QTest::addColumn<QUrl>("url");
-
-    QTest::newRow("system") << QString("/usr/bin") << QString("/usr") << QString("img/icon.png")
-                            << QUrl("file:///usr/share/gallery-app/rc/img/icon.png");
-    QTest::newRow("local") << QString("/home/user/dev/gallery/src") << QString("/usr") << QString("img/icon.png")
-                           << QUrl("file:///home/user/dev/gallery/src/../rc/img/icon.png");
-}
-void tst_Resource::get_rc_url()
-{
-    QFETCH(QString, appDir);
-    QFETCH(QString, installDir);
-    QFETCH(QString, path);
-    QFETCH(QUrl, url);
-
-    Resource resource(appDir, installDir, 0);
-    QCOMPARE(resource.get_rc_url(path), url);
-}
-
 void tst_Resource::maxTextureSize()
 {
-    Resource resource("", "", 0);
+    Resource resource(0);
     QCOMPARE(resource.maxTextureSize(), 0);
 }
 

=== removed file 'tests/unittests/unittests.pro'
--- tests/unittests/unittests.pro	2013-03-28 12:30:06 +0000
+++ tests/unittests/unittests.pro	1970-01-01 00:00:00 +0000
@@ -1,9 +0,0 @@
-include(../../coverage.pri)
-
-TEMPLATE = subdirs
-SUBDIRS += \
-    command-line-parser \
-    imaging \
-    gallerythumbnailimageprovider \
-    gallerystandardimageprovider \
-    resource

